airports

package module
v0.1.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 25, 2021 License: BSD-3-Clause Imports: 0 Imported by: 0

README

go-sfomuseum-airports

Go package for working with airports, in a SFO Museum context.

Install

You will need to have both Go (specifically version 1.12 or higher) and the make programs installed on your computer. Assuming you do just type:

make tools

All of this package's dependencies are bundled with the code in the vendor directory.

lookup

Lookup an airport by its IATA or ICAO code.

./bin/lookup EGLL
$> LHR EGLL "London Heathrow Airport" 102556703

$> ./bin/lookup YUL
YUL CYUL "Montreal-Pierre Elliott Trudeau International Airport" 102554351

See also

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Lookup

type Lookup interface {
	Find(string) ([]interface{}, error)
}

Directories

Path Synopsis
cmd
lookup command

Jump to