package
module
Version:
v0.1.5
Opens a new window with list of versions in this module.
Published: Jan 25, 2021
License: BSD-3-Clause
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
go-sfomuseum-airports
Go package for working with airports, in a SFO Museum context.
Install
You will need to have both Go (specifically version 1.12 or higher) and the make programs installed on your computer. Assuming you do just type:
make tools
All of this package's dependencies are bundled with the code in the vendor directory.
lookup
Lookup an airport by its IATA or ICAO code.
./bin/lookup EGLL
$> LHR EGLL "London Heathrow Airport" 102556703
$> ./bin/lookup YUL
YUL CYUL "Montreal-Pierre Elliott Trudeau International Airport" 102554351
See also
Documentation
¶
type Lookup interface {
Find(string) ([]interface{}, error)
}
Source Files
¶
Directories
¶
cmd
|
|
|
|
|
|
|
|
Click to show internal directories.
Click to hide internal directories.